---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1954-12-24;1228
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19550112&codiceRedaz=054U1228&dataVigenza=20251104
dataGU: 19550112
codiceRedaz: 054U1228
dataVigenza: 20251104
---

# Ordinamento delle anagrafi della popolazione residente.

La Camera dei deputati ed il Senato della Repubblica hanno

approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## Art. 1.

In ogni Comune deve essere tenuta l'anagrafe della popolazione residente. L'iscrizione e la richiesta di variazione anagrafica possono dar luogo alla verifica, da parte dei competenti uffici comunali, delle condizioni igienico-sanitarie dell'immobile in cui il richiedente intende fissare la propria residenza, ai sensi delle vigenti norme sanitarie. Nell'anagrafe della popolazione residente sono registrate le posizioni relative alle singole persone, alle famiglie ed alle convivenze, che hanno fissato nel Comune la residenza, nonche' le posizioni relative alle persone senza fissa dimora che hanno stabilito nel Comune il proprio domicilio, in conformita' del regolamento per l'esecuzione della presente legge. Gli atti anagrafici sono atti pubblici. Per l'esercizio delle funzioni di vigilanza di cui all'articolo 12, e' istituito, presso il Ministero dell'interno, l'Indice nazionale delle anagrafi (INA), alimentato e costantemente aggiornato, tramite collegamento informatico, da tutti i comuni. ((6. L'Indice nazionale delle anagrafi (INA) promuove la circolarita' delle informazioni anagrafiche essenziali al fine di consentire alle amministrazioni pubbliche centrali e locali collegate la disponibilita', in tempo reale, dei dati relativi alle generalita', alla cittadinanza, alla famiglia anagrafica, all'indirizzo anagrafico delle persone residenti in Italia e dei cittadini italiani residenti all'estero iscritti nell'Anagrafe degli italiani residenti all'estero (AIRE), certificati dai comuni e, limitatamente al codice fiscale, dall'Agenzia delle Entrate.)) Con decreto del Ministro dell'interno, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, di concerto con il Ministro per la funzione pubblica e il Ministro per l'innovazione e le tecnologie, sentiti il Centro nazionale per l'informatica nella pubblica amministrazione (CNIPA), il Garante per la protezione dei dati personali e l'Istituto nazionale di statistica (ISTAT), e' adottato il regolamento dell'INA. Il regolamento disciplina le modalita' di aggiornamento dell'INA da parte dei comuni e le modalita' per l'accesso da parte delle amministrazioni pubbliche centrali e locali al medesimo INA, per assicurarne la piena operativita'.

## Art. 2.

E' fatto obbligo ad ognuno di chiedere per se' e per le persone sulle quali esercita la patria potesta' o la tutela, la iscrizione nell'anagrafe del Comune di dimora abituale e di dichiarare alla stessa i fatti determinanti mutazione di posizioni anagrafiche, a norma del regolamento, fermo restando, agli effetti dell'articolo 44 del Codice civile, l'obbligo di denuncia del trasferimento anche all'anagrafe del Comune di precedente residenza. L'assenza temporanea dal Comune di dimora abituale non produce effetti sul riconoscimento della residenza. ((Ai fini dell'obbligo di cui al primo comma, la persona che non ha fissa dimora si considera residente nel comune dove ha stabilito il proprio domicilio. La persona stessa, al momento della richiesta di iscrizione, e' tenuta a fornire all'ufficio di anagrafe gli elementi necessari allo svolgimento degli accertamenti atti a stabilire l'effettiva sussistenza del domicilio. In mancanza del domicilio, si considera residente nel comune di nascita)). ((E' comunque istituito, senza nuovi o maggiori oneri a carico del bilancio dello Stato, presso il Ministero dell'interno un apposito registro nazionale delle persone che non hanno fissa dimora. Con decreto del Ministro dell'interno, da adottare nel termine di centottanta giorni dalla data di entrata in vigore della presente disposizione, sono stabilite le modalita' di funzionamento del registro attraverso l'utilizzo del sistema INA-SAIA)). Per i nati all'estero si considera Comune di residenza quello di nascita, del padre o, in mancanza, quello della madre. Per tutti gli altri, soggetti all'obbligo della residenza, ai quali non possano applicarsi i criteri sopraindicati, e' istituito apposito registro presso il Ministero dell'interno. Il personale diplomatico e consolare straniero, nonche' il personale straniero da esso dipendente, non sono soggetti all'obbligo dell'iscrizione anagrafica.

## Art. 3.

Il sindaco, quale ufficiale del Governo, e' ufficiale dell'anagrafe. Egli puo' delegare e revocare, in tutto o in parte, le funzioni di ufficiale d'anagrafe al segretario comunale o ad altri impiegati idonei del Comune. Ogni delegazione, munita della firma autografa del delegato, ed ogni revoca devono essere approvate dal prefetto.

## Art. 4.

L'ufficiale d'anagrafe provvede alla regolare tenuta dell'anagrafe della popolazione residente ed e' responsabile della esecuzione degli adempimenti prescritti per la formazione e la tenuta degli atti anagrafici. Egli ordina gli accertamenti necessari ad appurare la verita' dei fatti denunciati dagli interessati, relativi alle loro posizioni anagrafiche, e dispone indagini per accertare le contravvenzioni alle disposizioni della presente legge e del regolamento per la sua esecuzione. Egli invita le persone aventi obblighi anagrafici a presentarsi all'ufficio per fornire le notizie ed i chiarimenti necessari alla regolare tenuta dell'anagrafe. Puo' interpellare, allo stesso fine, gli enti, amministrazioni ed uffici pubblici e privati. Il personale dell'anagrafe ha l'obbligo di osservare il segreto su tutte le notizie di cui viene a conoscenza a causa delle sue funzioni.

## Art. 5.

L'ufficiale d'anagrafe che sia venuto a conoscenza di fatti che comportino l'istituzione o la mutazione di posizioni anagrafiche, per i quali non siano state rese le prescritte dichiarazioni, deve invitare gli interessati a renderle. In caso di mancata dichiarazione, l'ufficiale d'anagrafe provvede di ufficio, notificando all'interessato il provvedimento stesso. Contro il provvedimento d'ufficio e' ammesso ricorso al prefetto.

## Art. 6.

Gli ufficiali di stato civile devono comunicare il contenuto degli atti dello stato civile e delle relative annotazioni all'ufficio d'anagrafe del Comune di residenza delle persone cui gli atti o le annotazioni si riferiscono.

## Art. 7.

Nei Comuni con separati uffici di stato civile possono essere istituite, con decreto del prefetto della Provincia, separate anagrafi autonome con la stessa circoscrizione territoriale dei corrispondenti uffici di stato civile. Le circoscrizioni territoriali degli uffici separati di stato civile di uno stesso Comune, preveduti dall'art. 2 dell'ordinamento dello stato civile approvato con regio decreto 9 luglio 1939, n. 1238, devono corrispondere ad una o piu' delle frazioni geografiche di cui al primo comma dell'art. 9 della presente legge. Questa disposizione non si applica, agli uffici separati dei quartieri delle grandi citta'.

## Art. 8.

In ogni Comune deve essere tenuto lo schedario della popolazione temporanea. La popolazione temporanea e' costituita dalle persone che, dimorando nel Comune da non meno di quattro mesi, non vi abbiano, tuttavia, fissata la residenza.

## Art. 9.

Il Comune provvede alla individuazione e delimitazione delle localita' abitate, alla suddivisione del territorio comunale in frazioni geografiche con limiti definiti in base alle condizioni antropogeografiche rilevate, ed alla esecuzione degli adempimenti connessi, che saranno prescritti dal regolamento. I limiti ed i segni relativi agli adempimenti anzidetti saranno tracciati su carte topografiche concernenti il territorio comunale. Il piano topografico costituito dalle carte di cui al comma precedente sara' sottoposto, per l'esame e l'approvazione, all'Istituto centrale di statistica e sara' tenuto al corrente a cura del Comune.

## Art. 10.

Il Comune provvede alla indicazione dell'onomastica stradale e della numerazione civica. La spesa della numerazione civica puo' essere posta a carico dei proprietari dei fabbricati, con la procedura prevista dal secondo comma dell'art. 153 del testo unico della legge comunale e provinciale, approvato con regio decreto 4 febbraio 1915, n. 148. I proprietari di fabbricati provvedono alla indicazione della numerazione interna.

## Art. 11.

((

1. Salvo che il fatto costituisca reato, chiunque, avendo obblighi anagrafici, contravviene alle disposizioni della presente legge, della legge 27 ottobre 1988, n. 470, e dei regolamenti di esecuzione delle predette leggi e' soggetto alla sanzione pecuniaria amministrativa da 100 euro a 500 euro. La sanzione e' ridotta, sempreche' la violazione non sia stata gia' constatata e comunque non siano iniziate attivita' amministrative di accertamento delle quali l'autore della violazione abbia avuto formale conoscenza, ad un decimo del minimo di quella prevista se la comunicazione e' effettuata o la dichiarazione e' presentata con ritardo non superiore a novanta giorni.

2. Salvo che il fatto costituisca reato, l'omissione della dichiarazione di trasferimento di residenza dall'estero o all'estero entro il termine previsto rispettivamente dall'articolo 13, comma 2, del regolamento di cui al decreto del Presidente della Repubblica 30 maggio 1989, n. 223, o dall'articolo 6, commi 1 e 4, della legge 27 ottobre 1988, n. 470, e' soggetta alla sanzione amministrativa pecuniaria da 200 euro a 1.000 euro per ciascun anno in cui perdura l'omissione. La sanzione e' ridotta, sempreche' la violazione non sia stata gia' constatata e comunque non siano iniziate attivita' amministrative di accertamento delle quali l'autore della violazione abbia avuto formale conoscenza, ad un decimo del minimo di quella prevista se la dichiarazione e' presentata con ritardo non superiore a novanta giorni.

3. L'autorita' competente all'accertamento e all'irrogazione della sanzione e' il comune nella cui anagrafe e' iscritto il trasgressore. Per il procedimento accertativo e sanzionatorio si applicano le disposizioni della legge 24 novembre 1981, n. 689. L'accertamento e l'irrogazione delle sanzioni sono notificati, a pena di decadenza, entro il 31 dicembre del quinto anno successivo a quello in cui l'obbligo anagrafico non risulta adempiuto o la dichiarazione risulta omessa.

4. I proventi delle sanzioni di cui al presente articolo sono acquisiti al bilancio del comune che ha irrogato la sanzione))

--------------- AGGIORNAMENTO (1) Il D.L. 28 febbraio 1983, n. 55, convertito con modificazioni dalla L. 26 aprile 1983, n. 131, ha disposto (con l'art. 27, comma 9) che la misura delle sanzioni pecuniarie previste dal presente articolo e' decuplicata.

## Art. 12.

La vigilanza sulla tenuta delle anagrafi della popolazione residente e' esercitata dal Ministero dell'interno e dall'Istituto centrale di statistica. Nessuna annotazione sugli atti anagrafici, in aggiunta a quelle previste dalla presente legge e dal regolamento, puo' essere disposta senza l'autorizzazione del Ministero dell'interno d'intesa con l'Istituto centrale di statistica.

## Art. 13.

Su proposta del Presidente del Consiglio dei Ministri d'intesa con i Ministri per l'interno, per la grazia e giustizia e per il tesoro sara' emanato il regolamento per l'esecuzione della presente legge.

